@@ -1,8 +1,9 @@
-#ABSTRACT: The role to load the sha512 plugin (default for v1.0)
 package Archive::BagIt::Plugin::Manifest::SHA512;
+# ABSTRACT: The role to load the sha512 plugin (default for v1.0)
+our $VERSION = '0.074'; # VERSION
+
 use strict;
 use warnings;
-use Digest::SHA;
 use Moo;
 with 'Archive::BagIt::Role::Manifest';
 
@@ -55,7 +56,7 @@ Archive::BagIt::Plugin::Manifest::SHA512 - The role to load the sha512 plugin (d
 
 =head1 VERSION
 
-version 0.072
+version 0.074
 
 =head1 AVAILABILITY
 
